/*

*/
package scene;

/**
<pre>
   This is a (non-singular) orthographic projection matrix.
     [ 1  0  0  0 ]
     [ 0  1  0  0 ]
     [ 0  0  1  0 ]
     [ 0  0  0  1 ]
   Notice that this matrix maps
        (x, y, z, 1) -> (x, y, z, 1).
   This matrix transforms the standard view parallelepiped
   (in camera coordinates) into the standard view parallelepiped
   (in clip coordinates, which are also NDC in this case) and it
   translates the standard view plane from z = -1 (in camera
   coordinates) to z = -1 (in NDC).

   Notice that this is just the identity matrix, so of course it
   preserves depth information, which is what we are after. (Our
   previous orthographic projection transformations, based on our
   previous, singular, orthographic projection matrix, sent a solid,
   three-dimensional view parallelepiped to a flat, two-dimensional
   view rectangle, and lost all the depth information.)
</pre>
*/
public class OrthographicProjectionMatrix0 extends Matrix
{
   /**
   <pre>
      Construct this orthographic projection matrix.
        [ 1  0  0  0 ]
        [ 0  1  0  0 ]
        [ 0  0  1  0 ]
        [ 0  0  0  1 ]
   </pre>
   */
   public OrthographicProjectionMatrix0()
   {
      super(  new Vector(1.0, 0.0, 0.0, 0.0),
              new Vector(0.0, 1.0, 0.0, 0.0),
              new Vector(0.0, 0.0, 1.0, 0.0),
              new Vector(0.0, 0.0, 0.0, 1.0) );
   }
}

