/*

*/
package scene;

/**
<pre>
   This is a (non-singular) orthographic projection matrix.
     [ 1  0  0  0 ]
     [ 0  1  0  0 ]
     [ 0  0  1  1 ]
     [ 0  0  0  1 ]
   Notice that this matrix maps
        (x, y, z, 1) -> (x, y, z+1, 1).
   This matrix transforms the standard view parallelepiped
   (in camera coordinates) into the standard view parallelepiped
   (in clip coordinates, which are also NDC in this case) and it
   translates the standard view plane from z = -1 (in camera
   coordinates) to z = 0 (in NDC).

   Since a view parallelepiped is sent to a view parallelepiped,
   this transformation preserves depth information, which is what
   we are after. (Our previous orthographic projection transformations,
   based on our previous, singular, orthographic projection matrix,
   sent a solid, three-dimensional view parallelepiped to a flat,
   two-dimensional view rectangle, and lost all the depth information.)
</pre>
*/
public class OrthographicProjectionMatrix1 extends Matrix
{
   /**
   <pre>
      Construct this orthographic projection matrix.
        [ 1  0  0  0 ]
        [ 0  1  0  0 ]
        [ 0  0  1  1 ]
        [ 0  0  0  1 ]
   </pre>
   */
   public OrthographicProjectionMatrix1()
   {
      super(  new Vector(1.0, 0.0, 0.0, 0.0),
              new Vector(0.0, 1.0, 0.0, 0.0),
              new Vector(0.0, 0.0, 1.0, 0.0),
              new Vector(0.0, 0.0, 1.0, 1.0) );
   }
}
